==> apache-brooklyn-1.0.0-src.zip: apache-brooklyn-1.0.0-src/brooklyn-server/core/src/main/java/org/apache/brooklyn/core/location/internal/LocationDynamicType.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.brooklyn.core.location.internal;

import org.apache.brooklyn.core.location.AbstractLocation;
import org.apache.brooklyn.core.objs.BrooklynDynamicType;
import org.apache.brooklyn.api.location.Location;
import org.apache.brooklyn.api.location.LocationType;

public class LocationDynamicType extends BrooklynDynamicType<Location, AbstractLocation> {

    public LocationDynamicType(AbstractLocation location) {
        super(location);
    }
    
    @Override
    public LocationType getSnapshot() {
        return (LocationType) super.getSnapshot();
    }

    @Override
    protected LocationTypeSnapshot newSnapshot() {
        return new LocationTypeSnapshot(name, value(configKeys));
    }
}

==> apache-brooklyn-1.1.0-src.zip: apache-brooklyn-1.1.0-src/brooklyn-server/core/src/main/java/org/apache/brooklyn/core/location/internal/LocationDynamicType.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.brooklyn.core.location.internal;

import org.apache.brooklyn.core.location.AbstractLocation;
import org.apache.brooklyn.core.objs.BrooklynDynamicType;
import org.apache.brooklyn.api.location.Location;
import org.apache.brooklyn.api.location.LocationType;

public class LocationDynamicType extends BrooklynDynamicType<Location, AbstractLocation> {

    public LocationDynamicType(AbstractLocation location) {
        super(location);
    }
    
    @Override
    public LocationType getSnapshot() {
        return (LocationType) super.getSnapshot();
    }

    @Override
    protected LocationTypeSnapshot newSnapshot() {
        return new LocationTypeSnapshot(name, getConfigKeysModifiableCopy());
    }
}
